@@ -26,10 +26,10 @@
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
-#if HAVE_EXIF
+#ifdef HAVE_EXIF
 #include <libexif/exif-data.h>
 #endif
-#if HAVE_EXEMPI
+#ifdef HAVE_EXEMPI
 #include <exempi/xmp.h>
 #endif
 
@@ -62,12 +62,12 @@ GType               eog_metadata_details_get_type    (void) G_GNUC_CONST;
 G_GNUC_INTERNAL
 GtkWidget          *eog_metadata_details_new         (void);
 
-#if HAVE_EXIF
+#ifdef HAVE_EXIF
 G_GNUC_INTERNAL
 void                eog_metadata_details_update      (EogMetadataDetails *details,
 						      ExifData       *data);
 #endif
-#if HAVE_EXEMPI
+#ifdef HAVE_EXEMPI
 G_GNUC_INTERNAL
 void                eog_metadata_details_xmp_update  (EogMetadataDetails *view,
 						      XmpPtr          xmp_data);
